==> hqsoft_core-0.0.19.tar.gz: lib/core_base/service/permission_service.dart <==
import 'dart:io';

import 'package:permission_handler/permission_handler.dart';

class PermissionsService {
  PermissionsService._();

  static Future<bool> requestPermission(Permission permission) async {
    //var status = await permission.status;
    if (await permission.request().isGranted) {
      // Either the permission was already granted before or the user just granted it.
      return true;
    }
    return false;
  }

  //request permission by input
  //ex: Permission.location
  static Future<void> requestLocationPermission(
      {Function onPermissionDenied}) async {
    if (Platform.isAndroid) {
      onPermissionDenied();
    } else {
      bool isAllow = await openAppSettings();
      if (!isAllow) {
        onPermissionDenied();
      }
    }
  }

  static Future<bool> checkLocationPermissionStatus() async {
    //By default Geolocator will use FusedLocationProviderClient on Android when Google Play Services are available.
    // It will fall back to LocationManager when it is not available.
    // You can override the behaviour by setting forceAndroidLocationManager.

//    Geolocator geolocator = Geolocator()..forceAndroidLocationManager = true;
//    GeolocationStatus geolocationStatus  = await geolocator.checkGeolocationPermissionStatus(locationPermission: GeolocationPermission.locationWhenInUse);
//    if(geolocationStatus == GeolocationStatus.granted) {
//      return true;
//    }
//    return false;

    //Check status each permission
    Map<Permission, PermissionStatus> statuses = await [
      Permission.location,
      Permission.locationWhenInUse,
      Permission.locationAlways,
    ].request();
    var mapGranted =
        statuses.values.where((PermissionStatus status) => status.isGranted);

    return mapGranted.isNotEmpty ? true : false;
  }

  static Future<bool> checkLocationEnable() async {
    if (await Permission.location.serviceStatus.isEnabled ||
        await Permission.locationAlways.serviceStatus.isEnabled ||
        await Permission.locationWhenInUse.serviceStatus.isEnabled) {
      return true;
    }
    return false;
  }

  static Future<bool> checkNotificationPermissionStatus() async {
    Map<Permission, PermissionStatus> statuses =
        await [Permission.notification].request();
    var mapGranted =
        statuses.values.where((PermissionStatus status) => status.isGranted);
    return mapGranted.isNotEmpty ? true : false;
  }
}

==> hqsoft_core-0.0.81.tar.gz: lib/core_base/service/permission_service.dart <==
import 'dart:io';

import 'package:permission_handler/permission_handler.dart';

class PermissionsService {
  PermissionsService._();

  static Future<bool> requestPermission(Permission permission) async {
    //var status = await permission.status;
    if (await permission.request().isGranted) {
      // Either the permission was already granted before or the user just granted it.
      return true;
    }
    return false;
  }

  //request permission by input
  //ex: Permission.location
  static Future<void> requestLocationPermission(
      {Function? onPermissionDenied}) async {
    if (Platform.isAndroid) {
      onPermissionDenied!();
    } else {
      bool isAllow = await openAppSettings();
      if (!isAllow) {
        onPermissionDenied!();
      }
    }
  }

  static Future<bool> checkLocationPermissionStatus() async {
    //By default Geolocator will use FusedLocationProviderClient on Android when Google Play Services are available.
    // It will fall back to LocationManager when it is not available.
    // You can override the behaviour by setting forceAndroidLocationManager.

//    Geolocator geolocator = Geolocator()..forceAndroidLocationManager = true;
//    GeolocationStatus geolocationStatus  = await geolocator.checkGeolocationPermissionStatus(locationPermission: GeolocationPermission.locationWhenInUse);
//    if(geolocationStatus == GeolocationStatus.granted) {
//      return true;
//    }
//    return false;

    //Check status each permission
    Map<Permission, PermissionStatus> statuses = await [
      Permission.location,
      Permission.locationWhenInUse,
      Permission.locationAlways,
    ].request();
    var mapGranted =
        statuses.values.where((PermissionStatus status) => status.isGranted);

    return mapGranted.isNotEmpty ? true : false;
  }

  static Future<bool> checkLocationEnable() async {
    if (await Permission.location.serviceStatus.isEnabled ||
        await Permission.locationAlways.serviceStatus.isEnabled ||
        await Permission.locationWhenInUse.serviceStatus.isEnabled) {
      return true;
    }
    return false;
  }

  static Future<bool> checkNotificationPermissionStatus() async {
    Map<Permission, PermissionStatus> statuses =
        await [Permission.notification].request();
    var mapGranted =
        statuses.values.where((PermissionStatus status) => status.isGranted);
    return mapGranted.isNotEmpty ? true : false;
  }
}
